PyTRiPGUI Developer Notes
=========================

MVC Model
---------

https://stackoverflow.com/questions/26698628/mvc-design-with-qtdesigner-and-pyside

https://stackoverflow.com/questions/16772374/python-pyqt-mvc-pattern-model-class-to-work-with-view-and-object

http://developers-club.com/posts/139454/

For TreeView()
http://trevorius.com/scrapbook/uncategorized/pyqt-custom-abstractitemmodel/


QtDesigner
----------
Run qtdesigner with QT5::

    $ qtchooser -run-tool=designer -qt=5
